camelot.camelot.model.authentication.Party

Package camelot :: Package camelot :: Package model :: Module authentication :: Class Party |
[hide private]
[frames] | no frames]

# Class Party

source code

Base class for persons and organizations. Use this base class to refer to either persons or organisations in building authentication systems, contact management or CRM

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
name(self) | source code

Class Variables | [hide private]
| addresses = `OneToMany('PartyAddress', lazy= True)`
| contact_mechanisms = `OneToMany('PartyContactMechanism', lazy= `...``

Method Details | [hide private]

### name(self) | source code
Decorators: `@property`

Class Variable Details | [hide private]

  ### contact_mechanisms Value:
      OneToMany('PartyContactMechanism', lazy= True)